@@ -3072,8 +3072,8 @@
Note that you must use the entire name of the port as specified by
your operating system. For example, in Windows this would be COM1,
- COM2, etc.; Linux and MacOSX tend to use names similar to '/dev/xxxxxx'.
- For now, only Linux/UNIX, MacOSX, and Windows are supported.
+ COM2, etc.; Linux and macOS tend to use names similar to '/dev/xxxxxx'.
+ For now, only Linux/UNIX, macOS, and Windows are supported.
Support for the EEPROM portion of the AtariVox and SaveKey is currently
emulated. That is, a file will be created on your computer simulating the
diff --git a/src/common/FSNodeFactory.hxx b/src/common/FSNodeFactory.hxx
index 4519c95d5..c63c8204d 100644
--- a/src/common/FSNodeFactory.hxx
+++ b/src/common/FSNodeFactory.hxx
@@ -19,7 +19,7 @@
#define FSNODE_FACTORY_HXX
class AbstractFSNode;
-#if defined(BSPF_UNIX) || defined(BSPF_MAC_OSX)
+#if defined(BSPF_UNIX) || defined(BSPF_MACOS)
#include "FSNodePOSIX.hxx"
#elif defined(BSPF_WINDOWS)
#include "FSNodeWINDOWS.hxx"
@@ -45,7 +45,7 @@ class FilesystemNodeFactory
switch(type)
{
case SYSTEM:
- #if defined(BSPF_UNIX) || defined(BSPF_MAC_OSX)
+ #if defined(BSPF_UNIX) || defined(BSPF_MACOS)
return make_unique(path);
#elif defined(BSPF_WINDOWS)
return make_unique(path);
diff --git a/src/common/FrameBufferSDL2.cxx b/src/common/FrameBufferSDL2.cxx
index 833413666..f603300d0 100644
--- a/src/common/FrameBufferSDL2.cxx
+++ b/src/common/FrameBufferSDL2.cxx
@@ -189,12 +189,12 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode)
: SDL_WINDOWPOS_UNDEFINED_DISPLAY(displayIndex);
uInt32 flags = mode.fsIndex != -1 ? SDL_WINDOW_FULLSCREEN_DESKTOP : 0;
- // OSX seems to have issues with destroying the window, and wants to keep
- // the same handle
+ // macOS seems to have issues with destroying the window, and wants to
+ // keep the same handle
// Problem is, doing so on other platforms results in flickering when
// toggling fullscreen windowed mode
- // So we have a special case for OSX
-#ifndef BSPF_MAC_OSX
+ // So we have a special case for macOS
+#ifndef BSPF_MACOS
// Don't re-create the window if its size hasn't changed, as it's not
// necessary, and causes flashing in fullscreen mode
if(myWindow)
@@ -213,7 +213,7 @@ bool FrameBufferSDL2::setVideoMode(const string& title, const VideoMode& mode)
SDL_SetWindowTitle(myWindow, title.c_str());
}
#else
- // OSX wants to *never* re-create the window
+ // macOS wants to *never* re-create the window
// This sometimes results in the window being resized *after* it's displayed,
// but at least the code works and doesn't crash
if(myWindow)
@@ -346,7 +346,7 @@ void FrameBufferSDL2::setWindowIcon()
{
ASSERT_MAIN_THREAD;
-#ifndef BSPF_MAC_OSX // Currently not needed for OSX
+#ifndef BSPF_MACOS // Currently not needed for macOS
#include "stella_icon.hxx" // The Stella icon
SDL_Surface* surface = SDL_CreateRGBSurfaceFrom(stella_icon, 32, 32, 32,
diff --git a/src/common/MediaFactory.hxx b/src/common/MediaFactory.hxx
index a370b9a41..e48de5978 100644
--- a/src/common/MediaFactory.hxx
+++ b/src/common/MediaFactory.hxx
@@ -32,10 +32,10 @@
#include "SerialPortWINDOWS.hxx"
#include "SettingsWINDOWS.hxx"
#include "OSystemWINDOWS.hxx"
-#elif defined(BSPF_MAC_OSX)
- #include "SerialPortMACOSX.hxx"
- #include "SettingsMACOSX.hxx"
- #include "OSystemMACOSX.hxx"
+#elif defined(BSPF_MACOS)
+ #include "SerialPortMACOS.hxx"
+ #include "SettingsMACOS.hxx"
+ #include "OSystemMACOS.hxx"
extern "C" {
int stellaMain(int argc, char* argv[]);
}
@@ -73,8 +73,8 @@ class MediaFactory
return make_unique();
#elif defined(BSPF_WINDOWS)
return make_unique();
- #elif defined(BSPF_MAC_OSX)
- return make_unique();
+ #elif defined(BSPF_MACOS)
+ return make_unique();
#else
#error Unsupported platform for OSystem!
#endif
@@ -86,8 +86,8 @@ class MediaFactory
return make_unique(osystem);
#elif defined(BSPF_WINDOWS)
return make_unique(osystem);
- #elif defined(BSPF_MAC_OSX)
- return make_unique(osystem);
+ #elif defined(BSPF_MACOS)
+ return make_unique(osystem);
#else
#error Unsupported platform for Settings!
#endif
@@ -99,8 +99,8 @@ class MediaFactory
return make_unique();
#elif defined(BSPF_WINDOWS)
return make_unique();
- #elif defined(BSPF_MAC_OSX)
- return make_unique();
+ #elif defined(BSPF_MACOS)
+ return make_unique();
#else
return make_unique();
#endif
diff --git a/src/common/PKeyboardHandler.cxx b/src/common/PKeyboardHandler.cxx
index 66cc4b970..a8c2d669c 100644
--- a/src/common/PKeyboardHandler.cxx
+++ b/src/common/PKeyboardHandler.cxx
@@ -259,7 +259,7 @@ void PhysicalKeyboardHandler::handleEvent(StellaKey key, StellaMod mod, bool sta
// Control or Alt/Cmd combos first
if(StellaModTest::isAlt(mod) && state)
{
-#ifdef BSPF_MAC_OSX
+#ifdef BSPF_MACOS
// These keys work in all states
if(key == KBDK_Q)
{
diff --git a/src/common/StellaKeys.hxx b/src/common/StellaKeys.hxx
index 1bb99d8f5..8b340b6c6 100644
--- a/src/common/StellaKeys.hxx
+++ b/src/common/StellaKeys.hxx
@@ -417,7 +417,7 @@ namespace StellaModTest
{
inline bool isAlt(int mod)
{
-#if defined(BSPF_MAC_OSX) || defined(OSX_KEYS)
+#if defined(BSPF_MACOS) || defined(MACOS_KEYS)
return (mod & KBDM_GUI);
#else
return (mod & KBDM_ALT);
diff --git a/src/common/bspf.hxx b/src/common/bspf.hxx
index e178bc750..26f9347b0 100644
--- a/src/common/bspf.hxx
+++ b/src/common/bspf.hxx
@@ -90,7 +90,7 @@ static const string EmptyString("");
namespace BSPF
{
// Defines to help with path handling
- #if defined(BSPF_UNIX) || defined(BSPF_MAC_OSX)
+ #if defined(BSPF_UNIX) || defined(BSPF_MACOS)
static const string PATH_SEPARATOR = "/";
#define ATTRIBUTE_FMT_PRINTF __attribute__((__format__ (__printf__, 2, 0)))
#elif defined(BSPF_WINDOWS)
diff --git a/src/common/main.cxx b/src/common/main.cxx
index b3be4aee8..b2f37e187 100644
--- a/src/common/main.cxx
+++ b/src/common/main.cxx
@@ -44,7 +44,7 @@
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-#if defined(BSPF_MAC_OSX)
+#if defined(BSPF_MACOS)
int stellaMain(int argc, char* argv[])
#else
int main(int argc, char* argv[])
diff --git a/src/emucore/EventHandler.cxx b/src/emucore/EventHandler.cxx
index b78ac9d09..7a8c1ed4f 100644
--- a/src/emucore/EventHandler.cxx
+++ b/src/emucore/EventHandler.cxx
@@ -700,7 +700,7 @@ void EventHandler::setActionMappings(EventMode mode)
// There are some keys which are hardcoded. These should be represented too.
string prepend = "";
if(event == Event::Quit)
-#ifndef BSPF_MAC_OSX
+#ifndef BSPF_MACOS
prepend = "Ctrl Q";
#else
prepend = "Cmd Q";
diff --git a/src/emucore/Serializer.cxx b/src/emucore/Serializer.cxx
index ea068f32f..3144a4727 100644
--- a/src/emucore/Serializer.cxx
+++ b/src/emucore/Serializer.cxx
@@ -67,7 +67,7 @@ Serializer::Serializer()
{
myStream = make_unique(ios::in | ios::out | ios::binary);
- // For some reason, Windows and possibly OSX needs to store something in
+ // For some reason, Windows and possibly macOS needs to store something in
// the stream before it is used for the first time
if(myStream)
{
diff --git a/src/gui/AboutDialog.cxx b/src/gui/AboutDialog.cxx
index 85783a5d6..625a3350d 100644
--- a/src/gui/AboutDialog.cxx
+++ b/src/gui/AboutDialog.cxx
@@ -118,7 +118,7 @@ void AboutDialog::updateStrings(int page, int lines, string& title)
title = "The Stella Team";
ADD_ATEXT("\\L\\c0""Stephen Anthony");
ADD_ATEXT("\\L\\c2"" Lead developer, current maintainer for the");
- ADD_ATEXT("\\L\\c2"" Linux/OSX and Windows ports ");
+ ADD_ATEXT("\\L\\c2"" Linux, macOS and Windows ports ");
ADD_ATEXT("\\L\\c0""Christian Speckner");
ADD_ATEXT("\\L\\c2"" Emulation core development, TIA core");
ADD_ATEXT("\\L\\c0""Eckhard Stolberg");
diff --git a/src/gui/BrowserDialog.cxx b/src/gui/BrowserDialog.cxx
index 284835bc7..2b2ef5c1c 100644
--- a/src/gui/BrowserDialog.cxx
+++ b/src/gui/BrowserDialog.cxx
@@ -82,7 +82,7 @@ BrowserDialog::BrowserDialog(GuiObject* boss, const GUI::Font& font,
buttonWidth, buttonHeight, "Base Dir", kBaseDirCmd);
addFocusWidget(_basedirButton);
-#ifndef BSPF_MAC_OSX
+#ifndef BSPF_MACOS
b = new ButtonWidget(this, font, _w - 2 * (buttonWidth + 7), _h - buttonHeight - 10,
buttonWidth, buttonHeight, "Choose", kChooseCmd);
addFocusWidget(b);
diff --git a/src/gui/Dialog.cxx b/src/gui/Dialog.cxx
index be7fcd69d..3f861044f 100644
--- a/src/gui/Dialog.cxx
+++ b/src/gui/Dialog.cxx
@@ -727,7 +727,7 @@ void Dialog::addOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
_w = std::max(HBORDER * 2 + buttonWidth * 2 + BUTTON_GAP, _w);
-#ifndef BSPF_MAC_OSX
+#ifndef BSPF_MACOS
addOKWidget(new ButtonWidget(this, font, _w - 2 * buttonWidth - HBORDER - BUTTON_GAP,
_h - buttonHeight - VBORDER, buttonWidth, buttonHeight, okText, GuiObject::kOKCmd));
addCancelWidget(new ButtonWidget(this, font, _w - (buttonWidth + HBORDER),
diff --git a/src/gui/HelpDialog.cxx b/src/gui/HelpDialog.cxx
index 5c0ea6dbd..d2ece15c0 100644
--- a/src/gui/HelpDialog.cxx
+++ b/src/gui/HelpDialog.cxx
@@ -84,7 +84,7 @@ HelpDialog::HelpDialog(OSystem& osystem, DialogContainer& parent,
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
void HelpDialog::updateStrings(uInt8 page, uInt8 lines, string& title)
{
-#ifdef BSPF_MAC_OSX
+#ifdef BSPF_MACOS
#define ALT_ "Cmd"
#else
#define ALT_ "Alt"
@@ -102,7 +102,7 @@ void HelpDialog::updateStrings(uInt8 page, uInt8 lines, string& title)
{
case 1:
title = "Common commands";
-#ifndef BSPF_MAC_OSX
+#ifndef BSPF_MACOS
ADD_BIND("Ctrl Q", "Quit emulation");
#else
ADD_BIND("Cmd Q", "Quit emulation");
diff --git a/src/gui/LauncherDialog.cxx b/src/gui/LauncherDialog.cxx
index 9280e8288..8d360c4dc 100644
--- a/src/gui/LauncherDialog.cxx
+++ b/src/gui/LauncherDialog.cxx
@@ -131,7 +131,7 @@ LauncherDialog::LauncherDialog(OSystem& osystem, DialogContainer& parent,
// Add four buttons at the bottom
xpos = 10; ypos += myDir->getHeight() + 8;
-#ifndef BSPF_MAC_OSX
+#ifndef BSPF_MACOS
myStartButton = new ButtonWidget(this, font, xpos, ypos, (bwidth + 0) / 4, bheight,
"Select", kLoadROMCmd);
wid.push_back(myStartButton);
diff --git a/src/macosx/AboutBox.h b/src/macos/AboutBox.h
similarity index 92%
rename from src/macosx/AboutBox.h
rename to src/macos/AboutBox.h
index 6570f1241..339a726af 100644
--- a/src/macosx/AboutBox.h
+++ b/src/macos/AboutBox.h
@@ -18,8 +18,8 @@
#import
/**
- AboutBox window class and support functions for the Macintosh OS X
- SDL port of Stella.
+ AboutBox window class and support functions for the macOS
+ SDL2 port of Stella.
@author Mark Grebe
*/
diff --git a/src/macosx/AboutBox.m b/src/macos/AboutBox.m
similarity index 100%
rename from src/macosx/AboutBox.m
rename to src/macos/AboutBox.m
diff --git a/src/macosx/AboutBox.nib/classes.nib b/src/macos/AboutBox.nib/classes.nib
similarity index 100%
rename from src/macosx/AboutBox.nib/classes.nib
rename to src/macos/AboutBox.nib/classes.nib
diff --git a/src/macosx/AboutBox.nib/info.nib b/src/macos/AboutBox.nib/info.nib
similarity index 100%
rename from src/macosx/AboutBox.nib/info.nib
rename to src/macos/AboutBox.nib/info.nib
diff --git a/src/macosx/AboutBox.nib/keyedobjects.nib b/src/macos/AboutBox.nib/keyedobjects.nib
similarity index 100%
rename from src/macosx/AboutBox.nib/keyedobjects.nib
rename to src/macos/AboutBox.nib/keyedobjects.nib
diff --git a/src/macosx/AboutBox.nib/objects.nib b/src/macos/AboutBox.nib/objects.nib
similarity index 100%
rename from src/macosx/AboutBox.nib/objects.nib
rename to src/macos/AboutBox.nib/objects.nib
diff --git a/src/macosx/AboutBoxTextView.h b/src/macos/AboutBoxTextView.h
similarity index 89%
rename from src/macosx/AboutBoxTextView.h
rename to src/macos/AboutBoxTextView.h
index f38fa36aa..3c0492cee 100644
--- a/src/macosx/AboutBoxTextView.h
+++ b/src/macos/AboutBoxTextView.h
@@ -18,8 +18,8 @@
#import
/**
- AboutBoxTextView class and support functions for the Macintosh OS X
- SDL port of Stella.
+ AboutBoxTextView class and support functions for the macOS
+ SDL2 port of Stella.
@author Mark Grebe
*/
diff --git a/src/macosx/Credits.html b/src/macos/Credits.html
similarity index 98%
rename from src/macosx/Credits.html
rename to src/macos/Credits.html
index c16a003d1..d2d4164b7 100644
--- a/src/macosx/Credits.html
+++ b/src/macos/Credits.html
@@ -13,7 +13,7 @@ Copyright © 1995-2018 The Stella Team
Stella is now DonationWare!
https://stella-emu.github.io/donations.html
-Macintosh OS X version:
+macOS version:
Copyright © 2007-2018 Stephen Anthony
Copyright © 2005-2006 Mark Grebe
diff --git a/src/macos/English.lproj/InfoPlist.strings b/src/macos/English.lproj/InfoPlist.strings
new file mode 100755
index 000000000..009ada54f
--- /dev/null
+++ b/src/macos/English.lproj/InfoPlist.strings
@@ -0,0 +1,8 @@
+/* Localized versions of Info.plist keys */
+
+CFBundleName = "Stella";
+CFBundleShortVersionString = "Stella version 6.0";
+CFBundleGetInfoString = "Stella version 6.0";
+NSHumanReadableCopyright = "Stella macOS version by Stephen Anthony and Mark Grebe.";
+
+"Atari 2600 Cartridge File" = "Atari 2600 Cartridge File";
diff --git a/src/macosx/OSystemMACOSX.hxx b/src/macos/OSystemMACOS.hxx
similarity index 66%
rename from src/macosx/OSystemMACOSX.hxx
rename to src/macos/OSystemMACOS.hxx
index 2e62ff333..a22c3ded7 100644
--- a/src/macosx/OSystemMACOSX.hxx
+++ b/src/macos/OSystemMACOS.hxx
@@ -15,24 +15,24 @@
// this file, and for a DISCLAIMER OF ALL WARRANTIES.
//============================================================================
-#ifndef OSYSTEM_MACOSX_HXX
-#define OSYSTEM_MACOSX_HXX
+#ifndef OSYSTEM_MACOS_HXX
+#define OSYSTEM_MACOS_HXX
#include "OSystem.hxx"
/**
- This class defines UNIX-like OS's (MacOS X) system specific settings.
+ This class defines UNIX-like OS's (macOS) system-specific settings.
- @author Mark Grebe
+ @author Mark Grebe, Stephen Anthony
*/
-class OSystemMACOSX : public OSystem
+class OSystemMACOS : public OSystem
{
public:
/**
- Create a new MACOSX-specific operating system object
+ Create a new macOS-specific operating system object
*/
- OSystemMACOSX();
- virtual ~OSystemMACOSX() = default;
+ OSystemMACOS();
+ virtual ~OSystemMACOS() = default;
/**
Returns the default paths for loading/saving files.
@@ -42,10 +42,10 @@ class OSystemMACOSX : public OSystem
private:
// Following constructors and assignment operators not supported
- OSystemMACOSX(const OSystemMACOSX&) = delete;
- OSystemMACOSX(OSystemMACOSX&&) = delete;
- OSystemMACOSX& operator=(const OSystemMACOSX&) = delete;
- OSystemMACOSX& operator=(OSystemMACOSX&&) = delete;
+ OSystemMACOS(const OSystemMACOS&) = delete;
+ OSystemMACOS(OSystemMACOS&&) = delete;
+ OSystemMACOS& operator=(const OSystemMACOS&) = delete;
+ OSystemMACOS& operator=(OSystemMACOS&&) = delete;
};
#endif
diff --git a/src/macosx/Preferences.h b/src/macos/Preferences.h
similarity index 92%
rename from src/macosx/Preferences.h
rename to src/macos/Preferences.h
index 7e25d7055..e17ac0c68 100644
--- a/src/macosx/Preferences.h
+++ b/src/macos/Preferences.h
@@ -18,8 +18,8 @@
#import
/**
- Preferences class and support functions for the Macintosh OS X
- SDL port of Stella.
+ Preferences class and support functions for the macOS
+ SDL2 port of Stella.
@author Mark Grebe
*/
diff --git a/src/macosx/Preferences.m b/src/macos/Preferences.m
similarity index 100%
rename from src/macosx/Preferences.m
rename to src/macos/Preferences.m
diff --git a/src/macosx/SDLMain.h b/src/macos/SDLMain.h
similarity index 100%
rename from src/macosx/SDLMain.h
rename to src/macos/SDLMain.h
diff --git a/src/macosx/SDLMain.m b/src/macos/SDLMain.m
similarity index 100%
rename from src/macosx/SDLMain.m
rename to src/macos/SDLMain.m
diff --git a/src/macosx/SDLMain.nib/designable.nib b/src/macos/SDLMain.nib/designable.nib
similarity index 100%
rename from src/macosx/SDLMain.nib/designable.nib
rename to src/macos/SDLMain.nib/designable.nib
diff --git a/src/macosx/SDLMain.nib/keyedobjects.nib b/src/macos/SDLMain.nib/keyedobjects.nib
similarity index 100%
rename from src/macosx/SDLMain.nib/keyedobjects.nib
rename to src/macos/SDLMain.nib/keyedobjects.nib
diff --git a/src/macosx/SerialPortMACOSX.cxx b/src/macos/SerialPortMACOS.cxx
similarity index 86%
rename from src/macosx/SerialPortMACOSX.cxx
rename to src/macos/SerialPortMACOS.cxx
index 3587bb94b..444b54103 100644
--- a/src/macosx/SerialPortMACOSX.cxx
+++ b/src/macos/SerialPortMACOS.cxx
@@ -25,23 +25,23 @@
#include
#include
-#include "SerialPortMACOSX.hxx"
+#include "SerialPortMACOS.hxx"
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-SerialPortMACOSX::SerialPortMACOSX()
+SerialPortMACOS::SerialPortMACOS()
: SerialPort(),
myHandle(0)
{
}
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-SerialPortMACOSX::~SerialPortMACOSX()
+SerialPortMACOS::~SerialPortMACOS()
{
closePort();
}
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool SerialPortMACOSX::openPort(const string& device)
+bool SerialPortMACOS::openPort(const string& device)
{
myHandle = open(device.c_str(), O_RDWR | O_NOCTTY | O_NONBLOCK);
if(myHandle <= 0)
@@ -61,7 +61,7 @@ bool SerialPortMACOSX::openPort(const string& device)
}
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void SerialPortMACOSX::closePort()
+void SerialPortMACOS::closePort()
{
if(myHandle)
{
@@ -71,11 +71,11 @@ void SerialPortMACOSX::closePort()
}
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool SerialPortMACOSX::writeByte(const uInt8* data)
+bool SerialPortMACOS::writeByte(const uInt8* data)
{
if(myHandle)
{
-// cerr << "SerialPortMACOSX::writeByte " << (int)(*data) << endl;
+// cerr << "SerialPortMACOS::writeByte " << (int)(*data) << endl;
return write(myHandle, data, 1) == 1;
}
return false;
diff --git a/src/macosx/SerialPortMACOSX.hxx b/src/macos/SerialPortMACOS.hxx
similarity index 76%
rename from src/macosx/SerialPortMACOSX.hxx
rename to src/macos/SerialPortMACOS.hxx
index 7e788adf7..cd5b423d1 100644
--- a/src/macosx/SerialPortMACOSX.hxx
+++ b/src/macos/SerialPortMACOS.hxx
@@ -15,22 +15,22 @@
// this file, and for a DISCLAIMER OF ALL WARRANTIES.
//============================================================================
-#ifndef SERIALPORT_UNIX_HXX
-#define SERIALPORT_UNIX_HXX
+#ifndef SERIALPORT_MACOS_HXX
+#define SERIALPORT_MACOS_HXX
#include "SerialPort.hxx"
/**
- Implement reading and writing from a serial port under OSX. For now,
+ Implement reading and writing from a serial port under macOS. For now,
reading isn't actually supported at all.
@author Stephen Anthony & D. Spice
*/
-class SerialPortMACOSX : public SerialPort
+class SerialPortMACOS : public SerialPort
{
public:
- SerialPortMACOSX();
- virtual ~SerialPortMACOSX();
+ SerialPortMACOS();
+ virtual ~SerialPortMACOS();
/**
Open the given serial port with the specified attributes.
@@ -59,10 +59,10 @@ class SerialPortMACOSX : public SerialPort
private:
// Following constructors and assignment operators not supported
- SerialPortMACOSX(const SerialPortMACOSX&) = delete;
- SerialPortMACOSX(SerialPortMACOSX&&) = delete;
- SerialPortMACOSX& operator=(const SerialPortMACOSX&) = delete;
- SerialPortMACOSX& operator=(SerialPortMACOSX&&) = delete;
+ SerialPortMACOS(const SerialPortMACOS&) = delete;
+ SerialPortMACOS(SerialPortMACOS&&) = delete;
+ SerialPortMACOS& operator=(const SerialPortMACOS&) = delete;
+ SerialPortMACOS& operator=(SerialPortMACOS&&) = delete;
};
#endif
diff --git a/src/macosx/SettingsMACOSX.cxx b/src/macos/SettingsMACOS.cxx
similarity index 91%
rename from src/macosx/SettingsMACOSX.cxx
rename to src/macos/SettingsMACOS.cxx
index 5445a7320..8b4b3a7c8 100644
--- a/src/macosx/SettingsMACOSX.cxx
+++ b/src/macos/SettingsMACOS.cxx
@@ -15,7 +15,7 @@
// this file, and for a DISCLAIMER OF ALL WARRANTIES.
//============================================================================
-#include "SettingsMACOSX.hxx"
+#include "SettingsMACOS.hxx"
extern "C" {
void prefsSetString(const char* key, const char* value);
@@ -24,13 +24,13 @@ extern "C" {
}
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-SettingsMACOSX::SettingsMACOSX(OSystem& osystem)
+SettingsMACOS::SettingsMACOS(OSystem& osystem)
: Settings(osystem)
{
}
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void SettingsMACOSX::loadConfig()
+void SettingsMACOS::loadConfig()
{
string key, value;
char cvalue[4096];
@@ -46,7 +46,7 @@ void SettingsMACOSX::loadConfig()
}
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void SettingsMACOSX::saveConfig()
+void SettingsMACOS::saveConfig()
{
// Write out each of the key and value pairs
for(const auto& s: getInternalSettings())
diff --git a/src/macosx/SettingsMACOSX.hxx b/src/macos/SettingsMACOS.hxx
similarity index 70%
rename from src/macosx/SettingsMACOSX.hxx
rename to src/macos/SettingsMACOS.hxx
index c71101f2a..4394efacc 100644
--- a/src/macosx/SettingsMACOSX.hxx
+++ b/src/macos/SettingsMACOS.hxx
@@ -15,26 +15,26 @@
// this file, and for a DISCLAIMER OF ALL WARRANTIES.
//============================================================================
-#ifndef SETTINGS_MAC_OSX_HXX
-#define SETTINGS_MAC_OSX_HXX
+#ifndef SETTINGS_MACOS_HXX
+#define SETTINGS_MACOS_HXX
class OSystem;
#include "Settings.hxx"
/**
- This class defines Macintosh OSX system specific settings.
+ This class defines macOS system-specific settings.
- @author Mark Grebe
+ @author Mark Grebe, Stephen Anthony
*/
-class SettingsMACOSX : public Settings
+class SettingsMACOS : public Settings
{
public:
/**
Create a new UNIX settings object
*/
- explicit SettingsMACOSX(OSystem& osystem);
- virtual ~SettingsMACOSX() = default;
+ explicit SettingsMACOS(OSystem& osystem);
+ virtual ~SettingsMACOS() = default;
public:
/**
@@ -51,11 +51,11 @@ class SettingsMACOSX : public Settings
private:
// Following constructors and assignment operators not supported
- SettingsMACOSX() = delete;
- SettingsMACOSX(const SettingsMACOSX&) = delete;
- SettingsMACOSX(SettingsMACOSX&&) = delete;
- SettingsMACOSX& operator=(const SettingsMACOSX&) = delete;
- SettingsMACOSX& operator=(SettingsMACOSX&&) = delete;
+ SettingsMACOS() = delete;
+ SettingsMACOS(const SettingsMACOS&) = delete;
+ SettingsMACOS(SettingsMACOS&&) = delete;
+ SettingsMACOS& operator=(const SettingsMACOS&) = delete;
+ SettingsMACOS& operator=(SettingsMACOS&&) = delete;
};
#endif
diff --git a/src/macosx/Stella.icns b/src/macos/Stella.icns
similarity index 100%
rename from src/macosx/Stella.icns
rename to src/macos/Stella.icns
diff --git a/src/macosx/stella.xcodeproj/project.pbxproj b/src/macos/stella.xcodeproj/project.pbxproj
similarity index 99%
rename from src/macosx/stella.xcodeproj/project.pbxproj
rename to src/macos/stella.xcodeproj/project.pbxproj
index 697ca6d21..0b25eb460 100644
--- a/src/macosx/stella.xcodeproj/project.pbxproj
+++ b/src/macos/stella.xcodeproj/project.pbxproj
@@ -43,8 +43,6 @@
2D9173F909BA90380026E9FF /* EventHandler.hxx in Headers */ = {isa = PBXBuildFile; fileRef = 2D733D6F062895B2006265D9 /* EventHandler.hxx */; };
2D9173FA09BA90380026E9FF /* FrameBuffer.hxx in Headers */ = {isa = PBXBuildFile; fileRef = 2D733D71062895B2006265D9 /* FrameBuffer.hxx */; };
2D9173FB09BA90380026E9FF /* Settings.hxx in Headers */ = {isa = PBXBuildFile; fileRef = 2D733D77062895F1006265D9 /* Settings.hxx */; };
- 2D9173FC09BA90380026E9FF /* SettingsMACOSX.hxx in Headers */ = {isa = PBXBuildFile; fileRef = 2D94486C0629124700DD9879 /* SettingsMACOSX.hxx */; };
- 2D9173FF09BA90380026E9FF /* OSystemMACOSX.hxx in Headers */ = {isa = PBXBuildFile; fileRef = 2DDBEA0F0845709700812C11 /* OSystemMACOSX.hxx */; };
2D91740009BA90380026E9FF /* AboutDialog.hxx in Headers */ = {isa = PBXBuildFile; fileRef = 2DDBEAA4084578BF00812C11 /* AboutDialog.hxx */; };
2D91740109BA90380026E9FF /* AudioDialog.hxx in Headers */ = {isa = PBXBuildFile; fileRef = 2DDBEAA7084578BF00812C11 /* AudioDialog.hxx */; };
2D91740209BA90380026E9FF /* BrowserDialog.hxx in Headers */ = {isa = PBXBuildFile; fileRef = 2DDBEAA9084578BF00812C11 /* BrowserDialog.hxx */; };
@@ -145,9 +143,7 @@
2D9174A109BA90380026E9FF /* EventHandler.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 2D733D6E062895B2006265D9 /* EventHandler.cxx */; };
2D9174A209BA90380026E9FF /* FrameBuffer.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 2D733D70062895B2006265D9 /* FrameBuffer.cxx */; };
2D9174A309BA90380026E9FF /* Settings.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 2D944848062904E800DD9879 /* Settings.cxx */; };
- 2D9174A409BA90380026E9FF /* SettingsMACOSX.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 2D944866062911CD00DD9879 /* SettingsMACOSX.cxx */; };
2D9174A809BA90380026E9FF /* FSNodePOSIX.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 2DDBEA0C0845708800812C11 /* FSNodePOSIX.cxx */; };
- 2D9174A909BA90380026E9FF /* OSystemMACOSX.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 2DDBEA0E0845709700812C11 /* OSystemMACOSX.cxx */; };
2D9174AA09BA90380026E9FF /* AboutDialog.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 2DDBEAA3084578BF00812C11 /* AboutDialog.cxx */; };
2D9174AB09BA90380026E9FF /* AudioDialog.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 2DDBEAA6084578BF00812C11 /* AudioDialog.cxx */; };
2D9174AC09BA90380026E9FF /* BrowserDialog.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 2DDBEAA8084578BF00812C11 /* BrowserDialog.cxx */; };
@@ -235,8 +231,12 @@
DC1B2EC81E50036100F62837 /* TrakBall.hxx in Headers */ = {isa = PBXBuildFile; fileRef = DC1B2EC21E50036100F62837 /* TrakBall.hxx */; };
DC1BC6662066B4390076F74A /* PKeyboardHandler.cxx in Sources */ = {isa = PBXBuildFile; fileRef = DC1BC6642066B4390076F74A /* PKeyboardHandler.cxx */; };
DC1BC6672066B4390076F74A /* PKeyboardHandler.hxx in Headers */ = {isa = PBXBuildFile; fileRef = DC1BC6652066B4390076F74A /* PKeyboardHandler.hxx */; };
- DC1FC18A0DB3B2C7009B3DF7 /* SerialPortMACOSX.cxx in Sources */ = {isa = PBXBuildFile; fileRef = DC1FC1880DB3B2C7009B3DF7 /* SerialPortMACOSX.cxx */; };
- DC1FC18B0DB3B2C7009B3DF7 /* SerialPortMACOSX.hxx in Headers */ = {isa = PBXBuildFile; fileRef = DC1FC1890DB3B2C7009B3DF7 /* SerialPortMACOSX.hxx */; };
+ DC21E5BF21CA903E007D0E1A /* OSystemMACOS.cxx in Sources */ = {isa = PBXBuildFile; fileRef = DC21E5B921CA903E007D0E1A /* OSystemMACOS.cxx */; };
+ DC21E5C021CA903E007D0E1A /* OSystemMACOS.hxx in Headers */ = {isa = PBXBuildFile; fileRef = DC21E5BA21CA903E007D0E1A /* OSystemMACOS.hxx */; };
+ DC21E5C121CA903E007D0E1A /* SerialPortMACOS.cxx in Sources */ = {isa = PBXBuildFile; fileRef = DC21E5BB21CA903E007D0E1A /* SerialPortMACOS.cxx */; };
+ DC21E5C221CA903E007D0E1A /* SerialPortMACOS.hxx in Headers */ = {isa = PBXBuildFile; fileRef = DC21E5BC21CA903E007D0E1A /* SerialPortMACOS.hxx */; };
+ DC21E5C321CA903E007D0E1A /* SettingsMACOS.cxx in Sources */ = {isa = PBXBuildFile; fileRef = DC21E5BD21CA903E007D0E1A /* SettingsMACOS.cxx */; };
+ DC21E5C421CA903E007D0E1A /* SettingsMACOS.hxx in Headers */ = {isa = PBXBuildFile; fileRef = DC21E5BE21CA903E007D0E1A /* SettingsMACOS.hxx */; };
DC2874071F8F2278004BF21A /* TrapArray.hxx in Headers */ = {isa = PBXBuildFile; fileRef = DC2874061F8F2278004BF21A /* TrapArray.hxx */; };
DC2AADAE194F389C0026C7A4 /* CartDASH.cxx in Sources */ = {isa = PBXBuildFile; fileRef = DC2AADAA194F389C0026C7A4 /* CartDASH.cxx */; };
DC2AADAF194F389C0026C7A4 /* CartDASH.hxx in Headers */ = {isa = PBXBuildFile; fileRef = DC2AADAB194F389C0026C7A4 /* CartDASH.hxx */; };
@@ -785,15 +785,11 @@
2D9217FB0857CC88001D664B /* Font.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = Font.cxx; sourceTree = ""; };
2D9217FC0857CC88001D664B /* Font.hxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.h; path = Font.hxx; sourceTree = ""; };
2D944848062904E800DD9879 /* Settings.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = Settings.cxx; sourceTree = ""; };
- 2D944866062911CD00DD9879 /* SettingsMACOSX.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = SettingsMACOSX.cxx; sourceTree = ""; };
- 2D94486C0629124700DD9879 /* SettingsMACOSX.hxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.h; path = SettingsMACOSX.hxx; sourceTree = ""; };
2D9555D90880E78000466554 /* Cart3E.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = Cart3E.cxx; sourceTree = ""; };
2D9555DA0880E78000466554 /* Cart3E.hxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.h; path = Cart3E.hxx; sourceTree = ""; };
2D9555DD0880E79600466554 /* CpuDebug.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = CpuDebug.cxx; sourceTree = ""; };
2D9555DE0880E79600466554 /* CpuDebug.hxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.h; path = CpuDebug.hxx; sourceTree = ""; };
2DDBEA0C0845708800812C11 /* FSNodePOSIX.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = FSNodePOSIX.cxx; sourceTree = ""; };
- 2DDBEA0E0845709700812C11 /* OSystemMACOSX.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = OSystemMACOSX.cxx; sourceTree = ""; };
- 2DDBEA0F0845709700812C11 /* OSystemMACOSX.hxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.h; path = OSystemMACOSX.hxx; sourceTree = ""; };
2DDBEAA3084578BF00812C11 /* AboutDialog.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = AboutDialog.cxx; sourceTree = ""; };
2DDBEAA4084578BF00812C11 /* AboutDialog.hxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.h; path = AboutDialog.hxx; sourceTree = ""; };
2DDBEAA6084578BF00812C11 /* AudioDialog.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = AudioDialog.cxx; sourceTree = ""; };
@@ -938,8 +934,12 @@
DC1B2EC21E50036100F62837 /* TrakBall.hxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = TrakBall.hxx; sourceTree = ""; };
DC1BC6642066B4390076F74A /* PKeyboardHandler.cxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; path = PKeyboardHandler.cxx; sourceTree = ""; };
DC1BC6652066B4390076F74A /* PKeyboardHandler.hxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = PKeyboardHandler.hxx; sourceTree = ""; };
- DC1FC1880DB3B2C7009B3DF7 /* SerialPortMACOSX.cxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = SerialPortMACOSX.cxx; sourceTree = ""; };
- DC1FC1890DB3B2C7009B3DF7 /* SerialPortMACOSX.hxx */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.h; path = SerialPortMACOSX.hxx; sourceTree = ""; };
+ DC21E5B921CA903E007D0E1A /* OSystemMACOS.cxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; path = OSystemMACOS.cxx; sourceTree = SOURCE_ROOT; };
+ DC21E5BA21CA903E007D0E1A /* OSystemMACOS.hxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = OSystemMACOS.hxx; sourceTree = SOURCE_ROOT; };
+ DC21E5BB21CA903E007D0E1A /* SerialPortMACOS.cxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; path = SerialPortMACOS.cxx; sourceTree = SOURCE_ROOT; };
+ DC21E5BC21CA903E007D0E1A /* SerialPortMACOS.hxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = SerialPortMACOS.hxx; sourceTree = SOURCE_ROOT; };
+ DC21E5BD21CA903E007D0E1A /* SettingsMACOS.cxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; path = SettingsMACOS.cxx; sourceTree = SOURCE_ROOT; };
+ DC21E5BE21CA903E007D0E1A /* SettingsMACOS.hxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = SettingsMACOS.hxx; sourceTree = SOURCE_ROOT; };
DC2874061F8F2278004BF21A /* TrapArray.hxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = TrapArray.hxx; sourceTree = ""; };
DC2AADAA194F389C0026C7A4 /* CartDASH.cxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; path = CartDASH.cxx; sourceTree = ""; };
DC2AADAB194F389C0026C7A4 /* CartDASH.hxx */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.h; path = CartDASH.hxx; sourceTree = ""; };
@@ -1436,7 +1436,7 @@
2D6050CC0898776500C6DE89 /* emucore */,
2D6050FA0898786C00C6DE89 /* gui */,
DCD6FC5A11C281A1005DA767 /* libpng */,
- 2D6050C60898771C00C6DE89 /* macosx */,
+ 2D6050C60898771C00C6DE89 /* macos */,
2D6050C90898774B00C6DE89 /* unix */,
2D60513708987A5400C6DE89 /* yacc */,
DC3EE83B1E2C0E4400905161 /* zlib */,
@@ -1696,16 +1696,17 @@
path = common;
sourceTree = "";
};
- 2D6050C60898771C00C6DE89 /* macosx */ = {
+ 2D6050C60898771C00C6DE89 /* macos */ = {
isa = PBXGroup;
children = (
- 2DDBEA0E0845709700812C11 /* OSystemMACOSX.cxx */,
- 2DDBEA0F0845709700812C11 /* OSystemMACOSX.hxx */,
- DC1FC1880DB3B2C7009B3DF7 /* SerialPortMACOSX.cxx */,
- DC1FC1890DB3B2C7009B3DF7 /* SerialPortMACOSX.hxx */,
- 2D944866062911CD00DD9879 /* SettingsMACOSX.cxx */,
- 2D94486C0629124700DD9879 /* SettingsMACOSX.hxx */,
+ DC21E5B921CA903E007D0E1A /* OSystemMACOS.cxx */,
+ DC21E5BA21CA903E007D0E1A /* OSystemMACOS.hxx */,
+ DC21E5BB21CA903E007D0E1A /* SerialPortMACOS.cxx */,
+ DC21E5BC21CA903E007D0E1A /* SerialPortMACOS.hxx */,
+ DC21E5BD21CA903E007D0E1A /* SettingsMACOS.cxx */,
+ DC21E5BE21CA903E007D0E1A /* SettingsMACOS.hxx */,
);
+ name = macos;
path = macosx;
sourceTree = "";
};
@@ -2281,8 +2282,6 @@
2D9173F909BA90380026E9FF /* EventHandler.hxx in Headers */,
2D9173FA09BA90380026E9FF /* FrameBuffer.hxx in Headers */,
2D9173FB09BA90380026E9FF /* Settings.hxx in Headers */,
- 2D9173FC09BA90380026E9FF /* SettingsMACOSX.hxx in Headers */,
- 2D9173FF09BA90380026E9FF /* OSystemMACOSX.hxx in Headers */,
2D91740009BA90380026E9FF /* AboutDialog.hxx in Headers */,
DCF3A6EE1DFC75E3008A8AF3 /* DelayQueueMember.hxx in Headers */,
DC96162F1F817830008A2206 /* AtariMouseWidget.hxx in Headers */,
@@ -2363,6 +2362,7 @@
DC2C5EDB1F8F2403007D2A09 /* smartmod.hxx in Headers */,
DCE5CDE41BA10024005CD08A /* RiotRamWidget.hxx in Headers */,
DCF3A6E81DFC75E3008A8AF3 /* Background.hxx in Headers */,
+ DC21E5C021CA903E007D0E1A /* OSystemMACOS.hxx in Headers */,
DCFB9FAC1ECA2609004FD69B /* DelayQueueIteratorImpl.hxx in Headers */,
DCA078351F8C1B04008EFEE5 /* SDL_lib.hxx in Headers */,
DCDA03B11A2009BB00711920 /* CartWD.hxx in Headers */,
@@ -2405,7 +2405,6 @@
DC4613680D92C03600D8DAB9 /* RomAuditDialog.hxx in Headers */,
DC487FB70DA5350900E12499 /* AtariVox.hxx in Headers */,
DC11F78E0DB36933003B505E /* MT24LC256.hxx in Headers */,
- DC1FC18B0DB3B2C7009B3DF7 /* SerialPortMACOSX.hxx in Headers */,
DCA00FF80DBABCAD00C3823D /* RiotDebug.hxx in Headers */,
DC4AC6F00DC8DACB00CD3AD2 /* RiotWidget.hxx in Headers */,
DC4AC6F40DC8DAEF00CD3AD2 /* SaveKey.hxx in Headers */,
@@ -2438,6 +2437,7 @@
DC6F394E21B897F300897AD8 /* ThreadDebugging.hxx in Headers */,
DCC527D310B9DA19005E1287 /* M6502.hxx in Headers */,
DC3EE8661E2C0E6D00905161 /* inflate.h in Headers */,
+ DC21E5C221CA903E007D0E1A /* SerialPortMACOS.hxx in Headers */,
DCC527D510B9DA19005E1287 /* NullDev.hxx in Headers */,
DCC527D710B9DA19005E1287 /* System.hxx in Headers */,
CFE3F6161E84A9CE00A8204E /* CartCDF.hxx in Headers */,
@@ -2499,6 +2499,7 @@
DCAAE5DC1715887B0080BB82 /* CartCVWidget.hxx in Headers */,
DCAAE5DD1715887B0080BB82 /* CartDebugWidget.hxx in Headers */,
DC6DC921205DB879004A5FC3 /* PJoystickHandler.hxx in Headers */,
+ DC21E5C421CA903E007D0E1A /* SettingsMACOS.hxx in Headers */,
DCAAE5DF1715887B0080BB82 /* CartEFSCWidget.hxx in Headers */,
DCAAE5E11715887B0080BB82 /* CartEFWidget.hxx in Headers */,
DCDFF08220B781B0001227C0 /* DispatchResult.hxx in Headers */,
@@ -2711,9 +2712,7 @@
2D9174A109BA90380026E9FF /* EventHandler.cxx in Sources */,
2D9174A209BA90380026E9FF /* FrameBuffer.cxx in Sources */,
2D9174A309BA90380026E9FF /* Settings.cxx in Sources */,
- 2D9174A409BA90380026E9FF /* SettingsMACOSX.cxx in Sources */,
2D9174A809BA90380026E9FF /* FSNodePOSIX.cxx in Sources */,
- 2D9174A909BA90380026E9FF /* OSystemMACOSX.cxx in Sources */,
2D9174AA09BA90380026E9FF /* AboutDialog.cxx in Sources */,
2D9174AB09BA90380026E9FF /* AudioDialog.cxx in Sources */,
2D9174AC09BA90380026E9FF /* BrowserDialog.cxx in Sources */,
@@ -2778,6 +2777,7 @@
DCDFF08120B781B0001227C0 /* DispatchResult.cxx in Sources */,
2D9174FC09BA90380026E9FF /* RamWidget.cxx in Sources */,
DC2AADAE194F389C0026C7A4 /* CartDASH.cxx in Sources */,
+ DC21E5C121CA903E007D0E1A /* SerialPortMACOS.cxx in Sources */,
E007231F210FBF5E002CF343 /* FpsMeter.cxx in Sources */,
2D9174FD09BA90380026E9FF /* RomListWidget.cxx in Sources */,
DCF3A6F81DFC75E3008A8AF3 /* PaddleReader.cxx in Sources */,
@@ -2823,7 +2823,6 @@
DC4613670D92C03600D8DAB9 /* RomAuditDialog.cxx in Sources */,
DC487FB60DA5350900E12499 /* AtariVox.cxx in Sources */,
DC11F78D0DB36933003B505E /* MT24LC256.cxx in Sources */,
- DC1FC18A0DB3B2C7009B3DF7 /* SerialPortMACOSX.cxx in Sources */,
DCA00FF70DBABCAD00C3823D /* RiotDebug.cxx in Sources */,
DC047FEE1A4A6F3600348F0F /* JoystickDialog.cxx in Sources */,
DC4AC6EF0DC8DACB00CD3AD2 /* RiotWidget.cxx in Sources */,
@@ -2848,6 +2847,7 @@
DC6B2BA611037FF200F199A7 /* DiStella.cxx in Sources */,
CFE3F6151E84A9CE00A8204E /* CartCDF.cxx in Sources */,
DCA82C711FEB4E780059340F /* TimeMachine.cxx in Sources */,
+ DC21E5C321CA903E007D0E1A /* SettingsMACOS.cxx in Sources */,
DCD3F7C511340AAF00DBA3AE /* Genesis.cxx in Sources */,
DCAD60A81152F8BD00BC4184 /* CartDPCPlus.cxx in Sources */,
DC5ACB5B1FBFCE8E00A213FD /* DeveloperDialog.cxx in Sources */,
@@ -2905,6 +2905,7 @@
DCAAE5D71715887B0080BB82 /* Cart4KWidget.cxx in Sources */,
DCDA03B01A2009BB00711920 /* CartWD.cxx in Sources */,
DCC6A4B220A2622500863C59 /* SimpleResampler.cxx in Sources */,
+ DC21E5BF21CA903E007D0E1A /* OSystemMACOS.cxx in Sources */,
DCAAE5D91715887B0080BB82 /* Cart0840Widget.cxx in Sources */,
DCAAE5DB1715887B0080BB82 /* CartCVWidget.cxx in Sources */,
DCAAE5DE1715887B0080BB82 /* CartEFSCWidget.cxx in Sources */,
@@ -2996,7 +2997,7 @@
JOYSTICK_SUPPORT,
SOUND_SUPPORT,
WINDOWED_SUPPORT,
- BSPF_MAC_OSX,
+ BSPF_MACOS,
MAC_OSX,
);
HEADER_SEARCH_PATHS = (
@@ -3047,7 +3048,7 @@
JOYSTICK_SUPPORT,
SOUND_SUPPORT,
WINDOWED_SUPPORT,
- BSPF_MAC_OSX,
+ BSPF_MACOS,
MAC_OSX,
);
HEADER_SEARCH_PATHS = (
diff --git a/src/macosx/template.dmg.gz b/src/macos/template.dmg.gz
similarity index 100%
rename from src/macosx/template.dmg.gz
rename to src/macos/template.dmg.gz
diff --git a/src/macosx/English.lproj/InfoPlist.strings b/src/macosx/English.lproj/InfoPlist.strings
deleted file mode 100755
index ea21784d0..000000000
--- a/src/macosx/English.lproj/InfoPlist.strings
+++ /dev/null
@@ -1,8 +0,0 @@
-/* Localized versions of Info.plist keys */
-
-CFBundleName = "Stella";
-CFBundleShortVersionString = "Stella version 5.1";
-CFBundleGetInfoString = "Stella version 5.1";
-NSHumanReadableCopyright = "Stella MacOS X version by Stephen Anthony and Mark Grebe.";
-
-"Atari 2600 Cartridge File" = "Atari 2600 Cartridge File";
diff --git a/src/unix/FSNodePOSIX.hxx b/src/unix/FSNodePOSIX.hxx
index d6fb7346b..e88966cfb 100644
--- a/src/unix/FSNodePOSIX.hxx
+++ b/src/unix/FSNodePOSIX.hxx
@@ -20,7 +20,7 @@
#include "FSNode.hxx"
-#ifdef MACOSX
+#ifdef BSPF_MACOS
#include
#endif
@@ -39,7 +39,7 @@
#endif
/*
- * Implementation of the Stella file system API based on POSIX (for Linux and OSX)
+ * Implementation of the Stella file system API based on POSIX (for Linux and macOS)
*
* Parts of this class are documented in the base interface class, AbstractFSNode.
*/
diff --git a/src/zlib/zconf.h b/src/zlib/zconf.h
index 1911c7c7e..13379bf65 100644
--- a/src/zlib/zconf.h
+++ b/src/zlib/zconf.h
@@ -8,8 +8,8 @@
#ifndef ZCONF_H
#define ZCONF_H
-/* Added by SA: 2017-07-09 */
-#if defined(BSPF_UNIX) || defined(BSPF_MAC_OSX)
+/* Added by SA: 2018-12-18 */
+#if defined(BSPF_UNIX) || defined(BSPF_MACOS)
#define HAVE_UNISTD_H
#endif
#define HAVE_STDARG_H
diff --git a/src/macosx/AboutBoxTextView.m b/src/macos/AboutBoxTextView.m
similarity index 100%
rename from src/macosx/AboutBoxTextView.m
rename to src/macos/AboutBoxTextView.m
diff --git a/src/macosx/Cart.icns b/src/macos/Cart.icns
similarity index 100%
rename from src/macosx/Cart.icns
rename to src/macos/Cart.icns
diff --git a/src/macosx/Create_build.sh b/src/macos/Create_build.sh
similarity index 90%
rename from src/macosx/Create_build.sh
rename to src/macos/Create_build.sh
index 4618a464f..0685cd31d 100755
--- a/src/macosx/Create_build.sh
+++ b/src/macos/Create_build.sh
@@ -4,7 +4,7 @@
# usage:
# Create_build.sh
#
# The result will be a file called ~/Desktop/Stella--macosx.dmg
if [ $# != 1 ]; then
echo "usage: Create_build.sh version"
@@ -12,7 +12,7 @@ if [ $# != 1 ]; then
fi
VER="$1"
-DMG="Stella-${VER}-macosx.dmg"
+DMG="Stella-${VER}-macos.dmg"
DISK="/Volumes/Stella"
DEST=~/Desktop/${DMG}
@@ -4,7 +4,7 @@
# Create_build.sh
#
-# The result will be a file called ~/Desktop/Stella--macosx.dmg
+# The result will be a file called ~/Desktop/Stella--macos.dmg
if [ $# != 1 ]; then
echo "usage: Create_build.sh version"
diff --git a/src/macosx/Info-Stella.plist b/src/macos/Info-Stella.plist
similarity index 100%
rename from src/macosx/Info-Stella.plist
rename to src/macos/Info-Stella.plist
diff --git a/src/macosx/OSystemMACOSX.cxx b/src/macos/OSystemMACOS.cxx
similarity index 86%
rename from src/macosx/OSystemMACOSX.cxx
rename to src/macos/OSystemMACOS.cxx
index 4f24b69c5..2fbc5e54e 100644
--- a/src/macosx/OSystemMACOSX.cxx
+++ b/src/macos/OSystemMACOS.cxx
@@ -16,7 +16,7 @@
//============================================================================
#include "FSNode.hxx"
-#include "OSystemMACOSX.hxx"
+#include "OSystemMACOS.hxx"
/**
Each derived class is responsible for calling the following methods
@@ -29,24 +29,24 @@
*/
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-OSystemMACOSX::OSystemMACOSX()
+OSystemMACOS::OSystemMACOS()
: OSystem()
{
setBaseDir("~/Library/Application Support/Stella/");
// This will be overridden, as OSX uses plist files for settings
setConfigFile("~/Library/Application Support/Stella/stellarc");
}
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string OSystemMACOSX::defaultSaveDir() const
+string OSystemMACOS::defaultSaveDir() const
{
FilesystemNode desktop("~/Desktop/");
return desktop.isDirectory() ? desktop.getShortPath() : "~/";
}
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string OSystemMACOSX::defaultLoadDir() const
+string OSystemMACOS::defaultLoadDir() const
{
return defaultSaveDir();
}
@@ -29,24 +29,24 @@
{
setBaseDir("~/Library/Application Support/Stella/");
- // This will be overridden, as OSX uses plist files for settings
+ // This will be overridden, as macOS uses plist files for settings
setConfigFile("~/Library/Application Support/Stella/stellarc");
}